
# WaDI

[![Documentation](https://readthedocs.org/projects/wadi/badge/?version=latest&style=flat)](https://wadi.readthedocs.io/en/latest/#)
[![Pypi packaging](https://github.com/KWR-Water/wadi/actions/workflows/python-package.yml/badge.svg)](https://github.com/KWR-Water/wadi/actions/workflows/python-package.yml)

WaDI is a very generic importer for (almost) all (excel) formats in which water quality data of the (Dutch) water
laboratory is shared


## Installation

To get the latest stable version, use

```
  pip install wadi
```

# License

This package is MIT licensed. See [License File](https://github.com/KWR-Water/wadi/blob/master/LICENSE)

# Documentation

Documentation can be found on [readthedocs](https://wadi.readthedocs.io/en/latest/)
